"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkAndSignAuthMessage = void 0;
const constants_1 = require("@litprotocol-dev/constants");
const misc_1 = require("@litprotocol-dev/misc");
const cosmos_1 = require("./chains/cosmos");
const eth_1 = require("./chains/eth");
const sol_1 = require("./chains/sol");
/**
 *
 * Check for an existing cryptographic authentication signature and create one of it does not exist.  This is used to prove ownership of a given crypto wallet address to the Lit nodes.  The result is stored in LocalStorage so the user doesn't have to sign every time they perform an operation.
 *
 * @param { CheckAndSignAuthParams }
 *
 *  @returns { AuthSig } The AuthSig created or retrieved
 */
const checkAndSignAuthMessage = ({ chain, resources, switchChain, }) => {
    const chainInfo = constants_1.ALL_LIT_CHAINS[chain];
    console.log('chain:', chain);
    // -- validate: if chain info not found
    if (!chainInfo) {
        (0, misc_1.throwError)({
            message: `Unsupported chain selected.  Please select one of: ${Object.keys(constants_1.ALL_LIT_CHAINS)}`,
            error: constants_1.LIT_ERROR.UNSUPPORTED_CHAIN_EXCEPTION,
        });
    }
    // -- check and sign auth message based on chain
    if (chainInfo.vmType === constants_1.VMTYPE.EVM) {
        return (0, eth_1.checkAndSignEVMAuthMessage)({ chain, resources, switchChain });
    }
    else if (chainInfo.vmType === constants_1.VMTYPE.SVM) {
        return (0, sol_1.checkAndSignSolAuthMessage)();
    }
    else if (chainInfo.vmType === constants_1.VMTYPE.CVM) {
        return (0, cosmos_1.checkAndSignCosmosAuthMessage)({ chain });
    }
    else {
        return (0, misc_1.throwError)({
            message: `vmType not found for this chain: ${chain}.  This should not happen.  Unsupported chain selected.  Please select one of: ${Object.keys(constants_1.ALL_LIT_CHAINS)}`,
            error: constants_1.LIT_ERROR.UNSUPPORTED_CHAIN_EXCEPTION,
        });
    }
};
exports.checkAndSignAuthMessage = checkAndSignAuthMessage;
//# sourceMappingURL=auth-browser.js.map